@@ -787,7 +787,7 @@ class GenericConsumer(object):
             assoc = self.store.getAssociation(server_url, assoc_handle)
 
         if assoc:
-            if assoc.getExpiresIn() <= 0:
+            if assoc.expiresIn <= 0:
                 # XXX: It might be a good idea sometimes to re-start the
                 # authentication with a new association. Doing it
                 # automatically opens the possibility for
@@ -1361,7 +1361,7 @@ class GenericConsumer(object):
         # OpenID 1, but we'll accept it anyway, while issuing a
         # warning.
         if session_type == 'no-encryption':
-            logging.warn('OpenID server sent "no-encryption"'
+            logging.warning('OpenID server sent "no-encryption"'
                         'for OpenID 1.X')
 
         # Missing or empty session type is the way to flag a
