@@ -1,15 +1,16 @@
 from openid.consumer.discover import OpenIDServiceEndpoint
-from . import datadriven
+from openid.test import datadriven
+
 
 class BadLinksTestCase(datadriven.DataDrivenTestCase):
     cases = [
         '',
         "http://not.in.a.link.tag/",
         '<link rel="openid.server" href="not.in.html.or.head" />',
-        ]
+    ]
 
     def __init__(self, data):
-        datadriven.DataDrivenTestCase.__init__(self, data)
+        super(BadLinksTestCase, self).__init__(data)
         self.data = data
 
     def runOneTest(self):
@@ -17,5 +18,6 @@ class BadLinksTestCase(datadriven.DataDrivenTestCase):
         expected = []
         self.assertEqual(expected, actual)
 
+
 def pyUnitTests():
     return datadriven.loadTests(__name__)
